@@ -1,5 +1,5 @@
 use std::ops::{Deref, DerefMut};
-use bson2::Bson;
+use rbson::Bson;
 use serde::{Deserializer, Serializer};
 use serde::de::Error;
 
@@ -9,16 +9,16 @@ pub struct Bytes {
     pub inner: Vec<u8>,
 }
 
-impl From<bson2::Binary> for Bytes {
-    fn from(arg: bson2::Binary) -> Self {
+impl From<rbson::Binary> for Bytes {
+    fn from(arg: rbson::Binary) -> Self {
         Self {
             inner: arg.bytes
         }
     }
 }
 
-impl From<&bson2::Binary> for Bytes {
-    fn from(arg: &bson2::Binary) -> Self {
+impl From<&rbson::Binary> for Bytes {
+    fn from(arg: &rbson::Binary) -> Self {
         Self {
             inner: arg.bytes.clone()
         }
@@ -110,21 +110,21 @@ impl DerefMut for Bytes {
 
 #[cfg(test)]
 mod test {
-    use bson2::Bson;
+    use rbson::Bson;
     use crate::types::Bytes;
 
     #[test]
     fn test_ser_de() {
         let b = Bytes::from("111".as_bytes());
-        let bsons = bson2::to_bson(&b).unwrap();
+        let bsons = rbson::to_bson(&b).unwrap();
         match &bsons {
-            bson2::Bson::Binary(b) => {
-                assert_eq!(b.subtype, bson2::spec::BinarySubtype::Generic);
+            rbson::Bson::Binary(b) => {
+                assert_eq!(b.subtype, rbson::spec::BinarySubtype::Generic);
                 println!("yes is BinarySubtype::Generic");
             }
             _ => {}
         }
-        let b_de: Bytes = bson2::from_bson(bsons).unwrap();
+        let b_de: Bytes = rbson::from_bson(bsons).unwrap();
         assert_eq!(b, b_de);
         assert_eq!(b.inner, b_de.inner);
     }
